==> humanCHRLOC_1.16.1.tar.gz: humanCHRLOC/man/humanCHRLOC13START.Rd <==
\name{humanCHRLOC13START}
\alias{humanCHRLOC13START}
\title{An annotation data file for transciption starting locations of genes
on chromosome 13}
\description{
  humanCHRLOC13START maps Entrez Gene identifiers to the transciption starting
  locations of genes on chromosome number 13 corresponding to the
  Entrez Gene identifiers 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are Entrez Gene identifiers and values are the transciption starting location for
   genes. The starting positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors derived from the
   smallest starting value found for the Entrez Gene identifier. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\\url{http://gopher6/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Homo\_sapiens/database/}. Built: No build info available.

   Package built: Fri Mar 16 09:54:32 2007
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanCHRLOC13START)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}

==> humanCHRLOC_2.1.4.tar.gz: humanCHRLOC/man/humanCHRLOC13START.Rd <==
\name{humanCHRLOC13START}
\alias{humanCHRLOC13START}
\title{An annotation data file for transciption starting locations of genes
on chromosome 13}
\description{
  humanCHRLOC13START maps Entrez Gene identifiers to the transciption starting
  locations of genes on chromosome number 13 corresponding to the
  Entrez Gene identifiers 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are Entrez Gene identifiers and values are the transciption starting location for
   genes. The starting positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors derived from the
   smallest starting value found for the Entrez Gene identifier. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\url{http://gopher6/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Homo_sapiens/database/}. Built: No build info available.

   Package built: Thu Aug 30 09:54:07 2007
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanCHRLOC13START)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}
